==> vue-test-utils-compat-0.0.11.tgz: package/src/index.js <==
import { install as installWrapperAttributesCompat } from "./compats/wrapper-attributes.js";
import { install as installWrapperPropsCompat } from "./compats/wrapper-props.js";
import { install as installWrapperFindAllCompat, WrapperArray } from "./compats/wrapper-find-all.js";
import { install as installWrapperFindCompat } from "./compats/wrapper-find.js";
import { createLocalVue } from "./utils/create-local-vue.js";
import { normalizeMountArgs } from "./utils/normalize-mount-args.js";

const installedConfigs = new WeakMap();

function needsNormalization(config) {
  return (
    config.EXPORT_CREATE_LOCAL_VUE || Object.entries(config).some(([k, v]) => k.startsWith("MOUNT_ARGS") && Boolean(v))
  );
}

export const compatFlags = Object.freeze({
  EXPORT_CREATE_LOCAL_VUE: "EXPORT_CREATE_LOCAL_VUE",
  EXPORT_CREATE_WRAPPER: "EXPORT_CREATE_WRAPPER",
  EXPORT_ERROR_WRAPPER: "EXPORT_ERROR_WRAPPER",
  EXPORT_WRAPPER_ARRAY: "EXPORT_WRAPPER_ARRAY",

  GLOBAL_STUBS: "GLOBAL_STUBS",

  MOUNT_ARGS_COMPONENTS: "MOUNT_ARGS_COMPONENTS",
  MOUNT_ARGS_CONTEXT_ATTRS: "MOUNT_ARGS_CONTEXT_ATTRS",
  MOUNT_ARGS_CONTEXT_CHILDREN: "MOUNT_ARGS_CONTEXT_CHILDREN",
  MOUNT_ARGS_CONTEXT_CLASS: "MOUNT_ARGS_CONTEXT_CLASS",
  MOUNT_ARGS_CONTEXT_ON: "MOUNT_ARGS_CONTEXT_ON",
  MOUNT_ARGS_CONTEXT_PROPS: "MOUNT_ARGS_CONTEXT_PROPS",
  MOUNT_ARGS_DIRECTIVES: "MOUNT_ARGS_DIRECTIVES",
  MOUNT_ARGS_LISTENERS: "MOUNT_ARGS_LISTENERS",
  MOUNT_ARGS_MOCKS: "MOUNT_ARGS_MOCKS",
  MOUNT_ARGS_PROVIDE: "MOUNT_ARGS_PROVIDE",
  MOUNT_ARGS_SCOPED_SLOTS: "MOUNT_ARGS_SCOPED_SLOTS",
  MOUNT_ARGS_SCOPED_SLOTS_THIS: "MOUNT_ARGS_SCOPED_SLOTS_THIS",
  MOUNT_ARGS_STUBS: "MOUNT_ARGS_STUBS",

  WRAPPER_ATTRIBUTES_DISABLED: "WRAPPER_ATTRIBUTES_DISABLED",
  WRAPPER_ATTRIBUTES_VALUE: "WRAPPER_ATTRIBUTES_VALUE",
  WRAPPER_UNWRAP_PROPS: "WRAPPER_UNWRAP_PROPS",
  WRAPPER_DESTROY: "WRAPPER_DESTROY",
  WRAPPER_DO_NOT_INCLUDE_NATIVE_EVENTS_IN_EMITTED: "WRAPPER_DO_NOT_INCLUDE_NATIVE_EVENTS_IN_EMITTED",
  WRAPPER_DO_NOT_INCLUDE_HOOK_EVENTS_IN_EMITTED: "WRAPPER_DO_NOT_INCLUDE_HOOK_EVENTS_IN_EMITTED",
  WRAPPER_FIND_ALL: "WRAPPER_FIND_ALL",
  WRAPPER_FIND_BY_CSS_SELECTOR_RETURNS_COMPONENTS: "WRAPPER_FIND_BY_CSS_SELECTOR_RETURNS_COMPONENTS",
  WRAPPER_FIND_COMPONENT_BY_REF_RETURNS_DOM: "WRAPPER_FIND_COMPONENT_BY_REF_RETURNS_DOM",
  WRAPPER_SET_VALUE_DOES_NOT_TRIGGER_CHANGE: "WRAPPER_SET_VALUE_DOES_NOT_TRIGGER_CHANGE",
  WRAPPER_VUE_SET_VALUE_USES_DOM: "WRAPPER_VUE_SET_VALUE_USES_DOM",
});

export const fullCompatConfig = Object.freeze({
  ...Object.fromEntries(Object.keys(compatFlags).map((option) => [option, true])),
});

export function installCompat(VTU, compatConfig, vueH = null) {
  if (!VTU) {
    throw new Error("Unknown module for installation");
  }

  if (!compatConfig) {
    throw new Error("compatConfig is required");
  }

  const invalidOptions = Object.keys(compatConfig).filter((option) => !Object.keys(compatFlags).includes(option));
  if (invalidOptions.length > 0) {
    throw new Error(`Got unknown compat options: ${invalidOptions.join(", ")}`);
  }

  if (compatConfig.MOUNT_ARGS_SCOPED_SLOTS_THIS && !compatConfig.MOUNT_ARGS_SCOPED_SLOTS) {
    throw new Error("MOUNT_ARGS_SCOPED_SLOTS_THIS require MOUNT_ARGS_SCOPED_SLOTS compat to function");
  }

  if (compatConfig.MOUNT_ARGS_SCOPED_SLOTS_THIS && !vueH) {
    throw new Error("vueH (third parameter) is required when MOUNT_ARGS_SCOPED_SLOTS_THIS is used");
  }

  const installedCompatConfig = installedConfigs.get(VTU);
  if (installedCompatConfig && installedCompatConfig !== JSON.stringify(compatConfig)) {
    throw new Error(
      "You are trying to install compat layer to vue-test-utils, but it was already installed with different config"
    );
  }
  installedConfigs.set(VTU, JSON.stringify(compatConfig));

  if (compatConfig.GLOBAL_STUBS) {
    // eslint-disable-next-line no-param-reassign
    VTU.config.stubs = VTU.config.global.stubs;
  }

  if (compatConfig.EXPORT_CREATE_WRAPPER) {
    // eslint-disable-next-line no-param-reassign
    VTU.createWrapper = (vm) => (vm instanceof HTMLElement ? new VTU.DOMWrapper(vm) : new VTU.VueWrapper(null, vm));
    // eslint-disable-next-line no-param-reassign
    VTU.Wrapper = VTU.BaseWrapper;
    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.createWrapper = VTU.createWrapper;
      // eslint-disable-next-line no-param-reassign
      VTU.default.Wrapper = VTU.Wrapper;
    }
  }

  if (compatConfig.EXPORT_CREATE_LOCAL_VUE) {
    // eslint-disable-next-line no-param-reassign
    VTU.createLocalVue = createLocalVue;
    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.createLocalVue = VTU.createLocalVue;
    }
  }

  if (compatConfig.EXPORT_ERROR_WRAPPER) {
    // eslint-disable-next-line no-param-reassign
    VTU.ErrorWrapper = function ErrorWrapper(wrapperType) {
      return new Proxy(this, {
        get(obj, prop) {
          switch (prop) {
            case "then":
              // allows for better errors when wrapping `find` in `await`
              // https://github.com/vuejs/test-utils/issues/638
              return undefined;
            case "exists":
              return () => false;
            default:
              throw new Error(`Cannot call ${String(prop)} on an empty ${wrapperType}.`);
          }
        },
      });
    };

    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.ErrorWrapper = VTU.ErrorWrapper;
    }
  }

  if (compatConfig.EXPORT_WRAPPER_ARRAY) {
    // eslint-disable-next-line no-param-reassign
    VTU.WrapperArray = WrapperArray;
    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.WrapperArray = VTU.WrapperArray;
    }
  }

  if (compatConfig.WRAPPER_DESTROY) {
    VTU.config.plugins.VueWrapper.install((wrapper) => ({
      destroy: () => wrapper.unmount(),
    }));
    // eslint-disable-next-line no-param-reassign
    VTU.enableAutoDestroy = VTU.enableAutoUnmount;
    // eslint-disable-next-line no-param-reassign
    VTU.disableAutoDestroy = VTU.disableAutoUnmount;
    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.enableAutoDestroy = VTU.enableAutoDestroy;
      // eslint-disable-next-line no-param-reassign
      VTU.default.disableAutoDestroy = VTU.disableAutoDestroy;
    }
  }

  if (compatConfig.WRAPPER_FIND_ALL || compatConfig.WRAPPER_FIND_BY_CSS_SELECTOR_RETURNS_COMPONENTS) {
    installWrapperFindAllCompat(VTU, compatConfig);
  }

  if (
    compatConfig.WRAPPER_FIND_BY_CSS_SELECTOR_RETURNS_COMPONENTS ||
    compatConfig.WRAPPER_FIND_COMPONENT_BY_REF_RETURNS_DOM
  ) {
    installWrapperFindCompat(VTU, compatConfig);
  }

  if (compatConfig.WRAPPER_DO_NOT_INCLUDE_NATIVE_EVENTS_IN_EMITTED) {
    // eslint-disable-next-line no-param-reassign
    VTU.VueWrapper.prototype.attachNativeEventListener = () => {};
  }

  if (compatConfig.WRAPPER_DO_NOT_INCLUDE_HOOK_EVENTS_IN_EMITTED) {
    VTU.config.plugins.VueWrapper.install((wrapper) => {
      const { emitted } = wrapper;
      return {
        emitted(event) {
          const result = emitted.call(this, event);
          if (arguments.length === 1) {
            return result;
          }

          Object.keys(result).forEach((k) => {
            if (k.startsWith("hook:")) {
              delete result[k];
            }
          });
          return result;
        },
      };
    });
  }

  if (needsNormalization(compatConfig)) {
    const originalMount = VTU.mount;
    // eslint-disable-next-line no-param-reassign
    VTU.mount = function patchedMount(component, args) {
      return originalMount.call(this, component, normalizeMountArgs(args, compatConfig, vueH));
    };

    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.mount = VTU.mount;
    }

    const originalShallowMount = VTU.shallowMount;
    // eslint-disable-next-line no-param-reassign
    VTU.shallowMount = function patchedMount(component, args) {
      return originalShallowMount.call(this, component, normalizeMountArgs(args, compatConfig, vueH));
    };

    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.shallowMount = VTU.shallowMount;
    }
  }

  if (compatConfig.WRAPPER_ATTRIBUTES_VALUE || compatConfig.WRAPPER_ATTRIBUTES_DISABLED) {
    installWrapperAttributesCompat(VTU, compatConfig);
  }

  if (compatConfig.WRAPPER_UNWRAP_PROPS) {
    installWrapperPropsCompat(VTU, compatConfig);
  }

  if (compatConfig.WRAPPER_VUE_SET_VALUE_USES_DOM) {
    VTU.config.plugins.VueWrapper.install((wrapper) => ({
      setValue(value) {
        return new VTU.DOMWrapper(wrapper.element).setValue(value);
      },
    }));
  }

  if (compatConfig.WRAPPER_SET_VALUE_DOES_NOT_TRIGGER_CHANGE) {
    let blockTriggerringChange = false;
    VTU.config.plugins.DOMWrapper.install((wrapper) => {
      const { trigger, setValue } = wrapper;
      return {
        trigger(event, ...args) {
          if (blockTriggerringChange && event === "change") {
            return null;
          }

          return trigger.call(wrapper, event, ...args);
        },
        setValue(...args) {
          blockTriggerringChange = true;
          try {
            return setValue.call(wrapper, ...args);
          } finally {
            blockTriggerringChange = false;
          }
        },
      };
    });
  }
}

==> vue-test-utils-compat-0.0.12.tgz: package/src/index.js <==
import { install as installWrapperAttributesCompat } from "./compats/wrapper-attributes.js";
import { install as installWrapperPropsCompat } from "./compats/wrapper-props.js";
import { install as installWrapperFindAllCompat, WrapperArray } from "./compats/wrapper-find-all.js";
import { install as installWrapperFindCompat } from "./compats/wrapper-find.js";
import { createLocalVue } from "./utils/create-local-vue.js";
import { normalizeMountArgs } from "./utils/normalize-mount-args.js";

const installedConfigs = new WeakMap();

function needsNormalization(config) {
  return (
    config.EXPORT_CREATE_LOCAL_VUE || Object.entries(config).some(([k, v]) => k.startsWith("MOUNT_ARGS") && Boolean(v))
  );
}

export const compatFlags = Object.freeze({
  EXPORT_CREATE_LOCAL_VUE: "EXPORT_CREATE_LOCAL_VUE",
  EXPORT_CREATE_WRAPPER: "EXPORT_CREATE_WRAPPER",
  EXPORT_ERROR_WRAPPER: "EXPORT_ERROR_WRAPPER",
  EXPORT_WRAPPER_ARRAY: "EXPORT_WRAPPER_ARRAY",

  GLOBAL_STUBS: "GLOBAL_STUBS",

  MOUNT_ARGS_COMPONENTS: "MOUNT_ARGS_COMPONENTS",
  MOUNT_ARGS_CONTEXT_ATTRS: "MOUNT_ARGS_CONTEXT_ATTRS",
  MOUNT_ARGS_CONTEXT_CHILDREN: "MOUNT_ARGS_CONTEXT_CHILDREN",
  MOUNT_ARGS_CONTEXT_CLASS: "MOUNT_ARGS_CONTEXT_CLASS",
  MOUNT_ARGS_CONTEXT_ON: "MOUNT_ARGS_CONTEXT_ON",
  MOUNT_ARGS_CONTEXT_PROPS: "MOUNT_ARGS_CONTEXT_PROPS",
  MOUNT_ARGS_DIRECTIVES: "MOUNT_ARGS_DIRECTIVES",
  MOUNT_ARGS_LISTENERS: "MOUNT_ARGS_LISTENERS",
  MOUNT_ARGS_MOCKS: "MOUNT_ARGS_MOCKS",
  MOUNT_ARGS_PROVIDE: "MOUNT_ARGS_PROVIDE",
  MOUNT_ARGS_SCOPED_SLOTS: "MOUNT_ARGS_SCOPED_SLOTS",
  MOUNT_ARGS_SCOPED_SLOTS_THIS: "MOUNT_ARGS_SCOPED_SLOTS_THIS",
  MOUNT_ARGS_STUBS: "MOUNT_ARGS_STUBS",

  WRAPPER_ATTRIBUTES_DISABLED: "WRAPPER_ATTRIBUTES_DISABLED",
  WRAPPER_ATTRIBUTES_VALUE: "WRAPPER_ATTRIBUTES_VALUE",
  WRAPPER_ATTRIBUTES_FROM_ATTRS: "WRAPPER_ATTRIBUTES_FROM_ATTRS",
  WRAPPER_UNWRAP_PROPS: "WRAPPER_UNWRAP_PROPS",
  WRAPPER_DESTROY: "WRAPPER_DESTROY",
  WRAPPER_DO_NOT_INCLUDE_NATIVE_EVENTS_IN_EMITTED: "WRAPPER_DO_NOT_INCLUDE_NATIVE_EVENTS_IN_EMITTED",
  WRAPPER_DO_NOT_INCLUDE_HOOK_EVENTS_IN_EMITTED: "WRAPPER_DO_NOT_INCLUDE_HOOK_EVENTS_IN_EMITTED",
  WRAPPER_UNWRAP_EMITTED: "WRAPPER_UNWRAP_EMITTED",
  WRAPPER_FIND_ALL: "WRAPPER_FIND_ALL",
  WRAPPER_FIND_BY_CSS_SELECTOR_RETURNS_COMPONENTS: "WRAPPER_FIND_BY_CSS_SELECTOR_RETURNS_COMPONENTS",
  WRAPPER_FIND_COMPONENT_BY_REF_RETURNS_DOM: "WRAPPER_FIND_COMPONENT_BY_REF_RETURNS_DOM",
  WRAPPER_SET_VALUE_DOES_NOT_TRIGGER_CHANGE: "WRAPPER_SET_VALUE_DOES_NOT_TRIGGER_CHANGE",
  WRAPPER_VUE_SET_VALUE_USES_DOM: "WRAPPER_VUE_SET_VALUE_USES_DOM",
});

export const fullCompatConfig = Object.freeze({
  ...Object.fromEntries(Object.keys(compatFlags).map((option) => [option, true])),
});

export function installCompat(VTU, compatConfig, vueH = null) {
  if (!VTU) {
    throw new Error("Unknown module for installation");
  }

  if (!compatConfig) {
    throw new Error("compatConfig is required");
  }

  const invalidOptions = Object.keys(compatConfig).filter((option) => !Object.keys(compatFlags).includes(option));
  if (invalidOptions.length > 0) {
    throw new Error(`Got unknown compat options: ${invalidOptions.join(", ")}`);
  }

  if (compatConfig.MOUNT_ARGS_SCOPED_SLOTS_THIS && !compatConfig.MOUNT_ARGS_SCOPED_SLOTS) {
    throw new Error("MOUNT_ARGS_SCOPED_SLOTS_THIS require MOUNT_ARGS_SCOPED_SLOTS compat to function");
  }

  if (compatConfig.MOUNT_ARGS_SCOPED_SLOTS_THIS && !vueH) {
    throw new Error("vueH (third parameter) is required when MOUNT_ARGS_SCOPED_SLOTS_THIS is used");
  }

  const installedCompatConfig = installedConfigs.get(VTU);
  if (installedCompatConfig && installedCompatConfig !== JSON.stringify(compatConfig)) {
    throw new Error(
      "You are trying to install compat layer to vue-test-utils, but it was already installed with different config"
    );
  }
  installedConfigs.set(VTU, JSON.stringify(compatConfig));

  if (compatConfig.GLOBAL_STUBS) {
    // eslint-disable-next-line no-param-reassign
    VTU.config.stubs = VTU.config.global.stubs;
  }

  if (compatConfig.EXPORT_CREATE_WRAPPER) {
    // eslint-disable-next-line no-param-reassign
    VTU.createWrapper = (vm) => (vm instanceof HTMLElement ? new VTU.DOMWrapper(vm) : new VTU.VueWrapper(null, vm));
    // eslint-disable-next-line no-param-reassign
    VTU.Wrapper = VTU.BaseWrapper;
    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.createWrapper = VTU.createWrapper;
      // eslint-disable-next-line no-param-reassign
      VTU.default.Wrapper = VTU.Wrapper;
    }
  }

  if (compatConfig.EXPORT_CREATE_LOCAL_VUE) {
    // eslint-disable-next-line no-param-reassign
    VTU.createLocalVue = createLocalVue;
    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.createLocalVue = VTU.createLocalVue;
    }
  }

  if (compatConfig.EXPORT_ERROR_WRAPPER) {
    // eslint-disable-next-line no-param-reassign
    VTU.ErrorWrapper = function ErrorWrapper(wrapperType) {
      return new Proxy(this, {
        get(obj, prop) {
          switch (prop) {
            case "then":
              // allows for better errors when wrapping `find` in `await`
              // https://github.com/vuejs/test-utils/issues/638
              return undefined;
            case "exists":
              return () => false;
            default:
              throw new Error(`Cannot call ${String(prop)} on an empty ${wrapperType}.`);
          }
        },
      });
    };

    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.ErrorWrapper = VTU.ErrorWrapper;
    }
  }

  if (compatConfig.EXPORT_WRAPPER_ARRAY) {
    // eslint-disable-next-line no-param-reassign
    VTU.WrapperArray = WrapperArray;
    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.WrapperArray = VTU.WrapperArray;
    }
  }

  if (compatConfig.WRAPPER_DESTROY) {
    VTU.config.plugins.VueWrapper.install((wrapper) => ({
      destroy: () => wrapper.unmount(),
    }));
    // eslint-disable-next-line no-param-reassign
    VTU.enableAutoDestroy = VTU.enableAutoUnmount;
    // eslint-disable-next-line no-param-reassign
    VTU.disableAutoDestroy = VTU.disableAutoUnmount;
    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.enableAutoDestroy = VTU.enableAutoDestroy;
      // eslint-disable-next-line no-param-reassign
      VTU.default.disableAutoDestroy = VTU.disableAutoDestroy;
    }
  }

  if (compatConfig.WRAPPER_FIND_ALL || compatConfig.WRAPPER_FIND_BY_CSS_SELECTOR_RETURNS_COMPONENTS) {
    installWrapperFindAllCompat(VTU, compatConfig);
  }

  if (
    compatConfig.WRAPPER_FIND_BY_CSS_SELECTOR_RETURNS_COMPONENTS ||
    compatConfig.WRAPPER_FIND_COMPONENT_BY_REF_RETURNS_DOM
  ) {
    installWrapperFindCompat(VTU, compatConfig);
  }

  if (compatConfig.WRAPPER_DO_NOT_INCLUDE_NATIVE_EVENTS_IN_EMITTED) {
    // eslint-disable-next-line no-param-reassign
    VTU.VueWrapper.prototype.attachNativeEventListener = () => {};
  }

  if (compatConfig.WRAPPER_DO_NOT_INCLUDE_HOOK_EVENTS_IN_EMITTED || compatConfig.WRAPPER_UNWRAP_EMITTED) {
    VTU.config.plugins.VueWrapper.install((wrapper) => {
      const { emitted } = wrapper;
      return {
        emitted(event) {
          // eslint-disable-next-line no-underscore-dangle
          const unwrapEmittedEntry = (entry) => entry.map((obj) => obj?.__v_raw ?? obj);
          const result = emitted.call(this, event);
          if (arguments.length === 1) {
            if (compatConfig.WRAPPER_UNWRAP_EMITTED) {
              return result?.map(unwrapEmittedEntry);
            }
            return result;
          }

          Object.keys(result).forEach((k) => {
            if (compatConfig.WRAPPER_DO_NOT_INCLUDE_HOOK_EVENTS_IN_EMITTED) {
              if (k.startsWith("hook:")) {
                delete result[k];
                return;
              }
            }

            if (compatConfig.WRAPPER_UNWRAP_EMITTED) {
              result[k] = result[k]?.map(unwrapEmittedEntry);
            }
          });

          return result;
        },
      };
    });
  }

  if (needsNormalization(compatConfig)) {
    const originalMount = VTU.mount;
    // eslint-disable-next-line no-param-reassign
    VTU.mount = function patchedMount(component, args) {
      return originalMount.call(this, component, normalizeMountArgs(args, compatConfig, vueH));
    };

    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.mount = VTU.mount;
    }

    const originalShallowMount = VTU.shallowMount;
    // eslint-disable-next-line no-param-reassign
    VTU.shallowMount = function patchedMount(component, args) {
      return originalShallowMount.call(this, component, normalizeMountArgs(args, compatConfig, vueH));
    };

    if (VTU.default) {
      // eslint-disable-next-line no-param-reassign
      VTU.default.shallowMount = VTU.shallowMount;
    }
  }

  if (
    compatConfig.WRAPPER_ATTRIBUTES_VALUE ||
    compatConfig.WRAPPER_ATTRIBUTES_DISABLED ||
    compatConfig.WRAPPER_ATTRIBUTES_FROM_ATTRS
  ) {
    installWrapperAttributesCompat(VTU, compatConfig);
  }

  if (compatConfig.WRAPPER_UNWRAP_PROPS) {
    installWrapperPropsCompat(VTU, compatConfig);
  }

  if (compatConfig.WRAPPER_VUE_SET_VALUE_USES_DOM) {
    VTU.config.plugins.VueWrapper.install((wrapper) => ({
      setValue(value) {
        return new VTU.DOMWrapper(wrapper.element).setValue(value);
      },
    }));
  }

  if (compatConfig.WRAPPER_SET_VALUE_DOES_NOT_TRIGGER_CHANGE) {
    let blockTriggerringChange = false;
    VTU.config.plugins.DOMWrapper.install((wrapper) => {
      const { trigger, setValue } = wrapper;
      return {
        trigger(event, ...args) {
          if (blockTriggerringChange && event === "change") {
            return null;
          }

          return trigger.call(wrapper, event, ...args);
        },
        setValue(...args) {
          blockTriggerringChange = true;
          try {
            return setValue.call(wrapper, ...args);
          } finally {
            blockTriggerringChange = false;
          }
        },
      };
    });
  }
}
